fbchat\_muqit.Thread
====================

.. currentmodule:: fbchat_muqit

.. autoclass:: Thread

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Thread.__copy__
      ~Thread.__delattr__
      ~Thread.__dir__
      ~Thread.__eq__
      ~Thread.__format__
      ~Thread.__ge__
      ~Thread.__getattribute__
      ~Thread.__getstate__
      ~Thread.__gt__
      ~Thread.__hash__
      ~Thread.__init__
      ~Thread.__init_subclass__
      ~Thread.__le__
      ~Thread.__lt__
      ~Thread.__ne__
      ~Thread.__new__
      ~Thread.__reduce__
      ~Thread.__reduce_ex__
      ~Thread.__replace__
      ~Thread.__repr__
      ~Thread.__rich_repr__
      ~Thread.__setattr__
      ~Thread.__sizeof__
      ~Thread.__str__
      ~Thread.__subclasshook__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Thread.all_participants
      ~Thread.approval_mode
      ~Thread.description
      ~Thread.folder
      ~Thread.group_approval_queue
      ~Thread.image
      ~Thread.is_joined
      ~Thread.is_pinned
      ~Thread.joinable_link
      ~Thread.joinable_mode
      ~Thread.message_count
      ~Thread.name
      ~Thread.participants_nickname
      ~Thread.pinned_messages
      ~Thread.privacy_mode
      ~Thread.thread_admins
      ~Thread.thread_id
      ~Thread.thread_theme
      ~Thread.thread_type
      ~Thread.__annotations__
      ~Thread.__doc__
      ~Thread.__module__
      ~Thread.__slots__
      ~Thread.__struct_config__
      ~Thread.__struct_defaults__
      ~Thread.__struct_encode_fields__
      ~Thread.__struct_fields__
   
   